@@ -31,15 +31,14 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 	network "knative.dev/networking/pkg"
-	"knative.dev/pkg/metrics/metricskey"
 	"knative.dev/pkg/metrics/metricstest"
 	_ "knative.dev/pkg/metrics/testing"
 	rtesting "knative.dev/pkg/reconciler/testing"
-	"knative.dev/serving/pkg/activator/util"
 	v1 "knative.dev/serving/pkg/apis/serving/v1"
 	asmetrics "knative.dev/serving/pkg/autoscaler/metrics"
 	fakeservingclient "knative.dev/serving/pkg/client/injection/client/fake"
 	fakerevisioninformer "knative.dev/serving/pkg/client/injection/informers/serving/v1/revision/fake"
+	"knative.dev/serving/pkg/metrics"
 )
 
 const (
@@ -57,6 +56,7 @@ var (
 )
 
 type reqOp struct {
+	id   int
 	op   int
 	time int
 	key  types.NamespacedName
@@ -277,18 +277,22 @@ func TestStats(t *testing.T) {
 	}, {
 		name: "interleaved requests",
 		ops: []reqOp{{
+			id:   1,
 			op:   requestOpStart,
 			key:  rev1,
 			time: 0,
 		}, {
+			id:   2,
 			op:   requestOpStart,
 			key:  rev1,
 			time: 0,
 		}, {
+			id:   2,
 			op:   requestOpEnd,
 			key:  rev1,
 			time: 1,
 		}, {
+			id:   1,
 			op:   requestOpEnd,
 			key:  rev1,
 			time: 2,
@@ -317,14 +321,19 @@ func TestStats(t *testing.T) {
 			cr, _, cancel := newTestReporter(t)
 			defer cancel()
 
+			// statCache simulates the stat being kept for the entire request and reused
+			// for the request being finished.
+			statCache := map[int]*revisionStats{}
+
 			// Apply request operations
 			for _, op := range tc.ops {
 				time := time.Time{}.Add(time.Duration(op.time) * time.Millisecond)
 				switch op.op {
 				case requestOpStart:
-					cr.handleEvent(network.ReqEvent{Key: op.key, Type: network.ReqIn, Time: time})
+					statCache[op.id] = cr.handleRequestIn(network.ReqEvent{Key: op.key, Type: network.ReqIn, Time: time})
 				case requestOpEnd:
-					cr.handleEvent(network.ReqEvent{Key: op.key, Type: network.ReqOut, Time: time})
+					cr.handleRequestOut(statCache[op.id], network.ReqEvent{Key: op.key, Type: network.ReqOut, Time: time})
+					delete(statCache, op.id)
 				case requestOpTick:
 					stats := cr.report(time)
 					if len(stats) > 0 {
@@ -381,9 +390,9 @@ func TestConcurrencyReporterRun(t *testing.T) {
 	}()
 
 	now := time.Time{}
-	cr.handleEvent(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
-	cr.handleEvent(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
-	cr.handleEvent(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
+	cr.handleRequestIn(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
+	cr.handleRequestIn(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
+	cr.handleRequestIn(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
 
 	reportCh <- now.Add(1)
 
@@ -428,7 +437,7 @@ func TestConcurrencyReporterHandler(t *testing.T) {
 
 	resp := httptest.NewRecorder()
 	req := httptest.NewRequest(http.MethodPost, "http://example.com", nil)
-	rCtx := util.WithRevID(context.Background(), rev1)
+	rCtx := WithRevisionAndID(context.Background(), nil, rev1)
 
 	// Send a few requests.
 	handler.ServeHTTP(resp, req.WithContext(rCtx))
@@ -467,7 +476,7 @@ func TestConcurrencyReporterRace(t *testing.T) {
 
 	base := time.Now()
 
-	// 1. Request in: Creates the stat (first part of handleEvent)
+	// 1. Request in: Creates the stat (first part of handleRequestIn)
 	eventIn := network.ReqEvent{
 		Time: base,
 		Type: network.ReqIn,
@@ -475,14 +484,14 @@ func TestConcurrencyReporterRace(t *testing.T) {
 	}
 	stats, _ := cr.getOrCreateStat(eventIn)
 
-	// 2. Report (will remove the stat immediately)
+	// 2. Report (will remove the stat if not guarded correctly)
 	cr.report(base.Add(1 * time.Second))
 
 	// 3. HandleEvent (second part of handleEvent)
 	stats.stats.HandleEvent(eventIn)
 
 	// 4. Request out: Creates a new stat, now negative
-	cr.handleEvent(network.ReqEvent{
+	cr.handleRequestOut(stats, network.ReqEvent{
 		Time: base.Add(2 * time.Second),
 		Type: network.ReqOut,
 		Key:  rev1,
@@ -503,12 +512,12 @@ func TestConcurrencyReporterRace(t *testing.T) {
 	}
 
 	// 6. It continues to work correctly.
-	cr.handleEvent(network.ReqEvent{
+	stats = cr.handleRequestIn(network.ReqEvent{
 		Time: base.Add(2500 * time.Millisecond),
 		Type: network.ReqIn,
 		Key:  rev1,
 	})
-	cr.handleEvent(network.ReqEvent{
+	cr.handleRequestOut(stats, network.ReqEvent{
 		Time: base.Add(3 * time.Second),
 		Type: network.ReqOut,
 		Key:  rev1,
@@ -540,10 +549,10 @@ func TestMetricsReported(t *testing.T) {
 	}()
 
 	now := time.Time{}
-	cr.handleEvent(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
-	cr.handleEvent(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
-	cr.handleEvent(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
-	cr.handleEvent(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
+	cr.handleRequestIn(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
+	cr.handleRequestIn(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
+	cr.handleRequestIn(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
+	cr.handleRequestIn(network.ReqEvent{Key: rev1, Type: network.ReqIn, Time: now})
 
 	// Report
 	reportCh <- now.Add(1)
@@ -553,15 +562,15 @@ func TestMetricsReported(t *testing.T) {
 	wantResource := &resource.Resource{
 		Type: "knative_revision",
 		Labels: map[string]string{
-			metricskey.LabelRevisionName:      rev1.Name,
-			metricskey.LabelNamespaceName:     rev1.Namespace,
-			metricskey.LabelServiceName:       "service-" + rev1.Name,
-			metricskey.LabelConfigurationName: "config-" + rev1.Name,
+			metrics.LabelRevisionName:      rev1.Name,
+			metrics.LabelNamespaceName:     rev1.Namespace,
+			metrics.LabelServiceName:       "service-" + rev1.Name,
+			metrics.LabelConfigurationName: "config-" + rev1.Name,
 		},
 	}
 	wantTags := map[string]string{
-		metricskey.PodName:       "the-best-activator",
-		metricskey.ContainerName: "activator",
+		metrics.LabelPodName:       "the-best-activator",
+		metrics.LabelContainerName: "activator",
 	}
 
 	// Should report a concurrency of 3 because the first event was a scale-from-0 (gets discounted)
@@ -635,7 +644,7 @@ func BenchmarkConcurrencyReporterHandler(b *testing.B) {
 			Name:      testRevName + strconv.Itoa(i),
 		}
 		req := httptest.NewRequest(http.MethodGet, "http://example.com", nil)
-		reqs = append(reqs, req.WithContext(util.WithRevID(context.Background(), key)))
+		reqs = append(reqs, req.WithContext(WithRevisionAndID(context.Background(), nil, key)))
 
 		// Create revisions in the fake clients to trigger report logic.
 		rev := revision(key.Namespace, key.Name)
@@ -690,7 +699,7 @@ func BenchmarkConcurrencyReporterReport(b *testing.B) {
 				revisions.Informer().GetIndexer().Add(rev)
 
 				// Send a sample request for each revision to make sure it's reported.
-				cr.handleEvent(network.ReqEvent{
+				cr.handleRequestIn(network.ReqEvent{
 					Time: time.Now(),
 					Type: network.ReqIn,
 					Key:  key,
