@@ -21,7 +21,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"math/rand"
 	"net/http"
 	"net/http/httptest"
@@ -48,9 +48,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 
-	. "knative.dev/pkg/configmap/testing"
 	"knative.dev/pkg/logging"
-	_ "knative.dev/pkg/system/testing"
 )
 
 const (
@@ -125,7 +123,7 @@ func TestActivationHandler(t *testing.T) {
 
 			ctx, cancel, _ := rtesting.SetupFakeContextWithCancel(t)
 			defer cancel()
-			handler := New(ctx, test.throttler, rt)
+			handler := New(ctx, test.throttler, rt, false /*usePassthroughLb*/, logging.FromContext(ctx))
 
 			resp := httptest.NewRecorder()
 			req := httptest.NewRequest(http.MethodPost, "http://example.com", nil)
@@ -134,7 +132,7 @@ func TestActivationHandler(t *testing.T) {
 			// Set up config store to populate context.
 			configStore := setupConfigStore(t, logging.FromContext(ctx))
 			ctx = configStore.ToContext(ctx)
-			ctx = WithRevID(ctx, types.NamespacedName{Namespace: testNamespace, Name: testRevName})
+			ctx = WithRevisionAndID(ctx, nil, types.NamespacedName{Namespace: testNamespace, Name: testRevName})
 
 			handler.ServeHTTP(resp, req.WithContext(ctx))
 
@@ -142,7 +140,7 @@ func TestActivationHandler(t *testing.T) {
 				t.Fatalf("Unexpected response status. Want %d, got %d", test.wantCode, resp.Code)
 			}
 
-			gotBody, err := ioutil.ReadAll(resp.Body)
+			gotBody, err := io.ReadAll(resp.Body)
 			if err != nil {
 				t.Fatal("Error reading body:", err)
 			}
@@ -164,7 +162,7 @@ func TestActivationHandlerProxyHeader(t *testing.T) {
 	ctx, cancel, _ := rtesting.SetupFakeContextWithCancel(t)
 	defer cancel()
 
-	handler := New(ctx, fakeThrottler{}, rt)
+	handler := New(ctx, fakeThrottler{}, rt, false /*usePassthroughLb*/, logging.FromContext(ctx))
 
 	writer := httptest.NewRecorder()
 	req := httptest.NewRequest(http.MethodPost, "http://example.com", nil)
@@ -172,7 +170,7 @@ func TestActivationHandlerProxyHeader(t *testing.T) {
 	// Set up config store to populate context.
 	configStore := setupConfigStore(t, logging.FromContext(ctx))
 	ctx = configStore.ToContext(req.Context())
-	ctx = WithRevID(ctx, types.NamespacedName{Namespace: testNamespace, Name: testRevName})
+	ctx = WithRevisionAndID(ctx, nil, types.NamespacedName{Namespace: testNamespace, Name: testRevName})
 
 	handler.ServeHTTP(writer, req.WithContext(ctx))
 
@@ -186,6 +184,43 @@ func TestActivationHandlerProxyHeader(t *testing.T) {
 	}
 }
 
+func TestActivationHandlerPassthroughLb(t *testing.T) {
+	interceptCh := make(chan *http.Request, 1)
+	rt := pkgnet.RoundTripperFunc(func(r *http.Request) (*http.Response, error) {
+		interceptCh <- r
+		fake := httptest.NewRecorder()
+		return fake.Result(), nil
+	})
+
+	ctx, cancel, _ := rtesting.SetupFakeContextWithCancel(t)
+	defer cancel()
+
+	handler := New(ctx, fakeThrottler{}, rt, true /*usePassthroughLb*/, logging.FromContext(ctx))
+
+	writer := httptest.NewRecorder()
+	req := httptest.NewRequest(http.MethodPost, "http://example.com", nil)
+
+	// Set up config store to populate context.
+	configStore := activatorconfig.NewStore(logging.FromContext(ctx))
+	configStore.OnConfigChanged(tracingConfig(false))
+	ctx = configStore.ToContext(req.Context())
+	ctx = WithRevisionAndID(ctx, nil, types.NamespacedName{Namespace: testNamespace, Name: testRevName})
+
+	handler.ServeHTTP(writer, req.WithContext(ctx))
+
+	select {
+	case httpReq := <-interceptCh:
+		if got, want := httpReq.Host, "real-name-private.real-namespace"; got != want {
+			t.Errorf("Host = %q, want: %q", got, want)
+		}
+		if got, want := httpReq.Header.Get(network.PassthroughLoadbalancingHeaderName), "true"; got != want {
+			t.Errorf("Header %q = %q, want: %q", "Host", got, want)
+		}
+	case <-time.After(1 * time.Second):
+		t.Error("Timed out waiting for a request to be intercepted")
+	}
+}
+
 func TestActivationHandlerTraceSpans(t *testing.T) {
 	testcases := []struct {
 		name         string
@@ -241,7 +276,7 @@ func TestActivationHandlerTraceSpans(t *testing.T) {
 				oct.Finish()
 			}()
 
-			handler := New(ctx, fakeThrottler{}, rt)
+			handler := New(ctx, fakeThrottler{}, rt, false /*usePassthroughLb*/, logging.FromContext(ctx))
 
 			// Set up config store to populate context.
 			configStore := setupConfigStore(t, logging.FromContext(ctx))
@@ -267,7 +302,7 @@ func sendRequest(namespace, revName string, handler http.Handler, store *activat
 	resp := httptest.NewRecorder()
 	req := httptest.NewRequest(http.MethodPost, "http://example.com/", nil)
 	ctx := store.ToContext(req.Context())
-	ctx = WithRevID(ctx, types.NamespacedName{Namespace: namespace, Name: revName})
+	ctx = WithRevisionAndID(ctx, nil, types.NamespacedName{Namespace: namespace, Name: revName})
 	handler.ServeHTTP(resp, req.WithContext(ctx))
 	return resp
 }
@@ -288,37 +323,36 @@ func revision(namespace, name string) *v1.Revision {
 	}
 }
 
-func setupConfigStore(t *testing.T, logger *zap.SugaredLogger) *activatorconfig.Store {
+func setupConfigStore(t testing.TB, logger *zap.SugaredLogger) *activatorconfig.Store {
 	configStore := activatorconfig.NewStore(logger)
-	tracingConfig := ConfigMapFromTestFile(t, tracingconfig.ConfigName)
-	configStore.OnConfigChanged(tracingConfig)
+	configStore.OnConfigChanged(tracingConfig(false))
 	return configStore
 }
 
 func BenchmarkHandler(b *testing.B) {
-	ctx, cancel, _ := rtesting.SetupFakeContextWithCancel(&testing.T{})
+	ctx, cancel, _ := rtesting.SetupFakeContextWithCancel(b)
 	b.Cleanup(cancel)
-	configStore := setupConfigStore(&testing.T{}, logging.FromContext(ctx))
+	configStore := setupConfigStore(b, logging.FromContext(ctx))
 
-	// bodyLength is in kilobytes.
+	// bodyLength is in Kilobytes.
 	for _, bodyLength := range [5]int{2, 16, 32, 64, 128} {
 		body := []byte(randomString(1024 * bodyLength))
 
 		rt := pkgnet.RoundTripperFunc(func(*http.Request) (*http.Response, error) {
 			return &http.Response{
-				Body:       ioutil.NopCloser(bytes.NewReader(body)),
+				Body:       io.NopCloser(bytes.NewReader(body)),
 				StatusCode: http.StatusOK,
 			}, nil
 		})
 
-		handler := New(ctx, fakeThrottler{}, rt)
+		handler := New(ctx, fakeThrottler{}, rt, false /*usePassthroughLb*/, logging.FromContext(ctx))
 
 		request := func() *http.Request {
 			req := httptest.NewRequest(http.MethodGet, "http://example.com", nil)
 			req.Host = "test-host"
 
 			reqCtx := configStore.ToContext(context.Background())
-			reqCtx = WithRevID(reqCtx, types.NamespacedName{Namespace: testNamespace, Name: testRevName})
+			reqCtx = WithRevisionAndID(reqCtx, nil, types.NamespacedName{Namespace: testNamespace, Name: testRevName})
 			return req.WithContext(reqCtx)
 		}
 
