@@ -17,12 +17,14 @@ limitations under the License.
 package serving
 
 import (
+	"context"
 	"testing"
 
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"knative.dev/pkg/kmp"
 	"knative.dev/pkg/ptr"
+	"knative.dev/serving/pkg/apis/config"
 )
 
 func TestVolumeMask(t *testing.T) {
@@ -32,19 +34,19 @@ func TestVolumeMask(t *testing.T) {
 	}
 	in := want
 
-	got := VolumeMask(in)
+	got := VolumeMask(context.Background(), in)
 
 	if &want == &got {
 		t.Error("Input and output share addresses. Want different addresses")
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("VolumeMask (-want, +got): %s", diff)
+		t.Error("VolumeMask (-want, +got):", diff)
 	}
 
-	if got = VolumeMask(nil); got != nil {
+	if got = VolumeMask(context.Background(), nil); got != nil {
 		t.Errorf("VolumeMask(nil) = %v, want: nil", got)
 	}
 }
@@ -60,19 +62,19 @@ func TestVolumeSourceMask(t *testing.T) {
 		NFS:       &corev1.NFSVolumeSource{},
 	}
 
-	got := VolumeSourceMask(in)
+	got := VolumeSourceMask(context.Background(), in)
 
 	if &want == &got {
 		t.Error("Input and output share addresses. Want different addresses")
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("VolumeSourceMask (-want, +got): %s", diff)
+		t.Error("VolumeSourceMask (-want, +got):", diff)
 	}
 
-	if got = VolumeSourceMask(nil); got != nil {
+	if got = VolumeSourceMask(context.Background(), nil); got != nil {
 		t.Errorf("VolumeSourceMask(nil) = %v, want: nil", got)
 	}
 }
@@ -117,19 +119,20 @@ func TestPodSpecMask(t *testing.T) {
 		}},
 	}
 
-	got := PodSpecMask(in)
+	ctx := context.Background()
+	got := PodSpecMask(ctx, in)
 
 	if &want == &got {
 		t.Error("Input and output share addresses. Want different addresses")
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("PodSpecMask (-want, +got): %s", diff)
+		t.Error("PodSpecMask (-want, +got):", diff)
 	}
 
-	if got = PodSpecMask(nil); got != nil {
+	if got = PodSpecMask(ctx, nil); got != nil {
 		t.Errorf("PodSpecMask(nil) = %v, want: nil", got)
 	}
 }
@@ -180,9 +183,9 @@ func TestContainerMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("ContainerMask (-want, +got): %s", diff)
+		t.Error("ContainerMask (-want, +got):", diff)
 	}
 
 	if got = ContainerMask(nil); got != nil {
@@ -214,9 +217,9 @@ func TestVolumeMountMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("VolumeMountMask (-want, +got): %s", diff)
+		t.Error("VolumeMountMask (-want, +got):", diff)
 	}
 
 	if got = VolumeMountMask(nil); got != nil {
@@ -242,9 +245,9 @@ func TestProbeMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("ProbeMask (-want, +got): %s", diff)
+		t.Error("ProbeMask (-want, +got):", diff)
 	}
 
 	if got = ProbeMask(nil); got != nil {
@@ -267,9 +270,9 @@ func TestHandlerMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("HandlerMask (-want, +got): %s", diff)
+		t.Error("HandlerMask (-want, +got):", diff)
 	}
 
 	if got = HandlerMask(nil); got != nil {
@@ -290,9 +293,9 @@ func TestExecActionMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("ExecActionMask (-want, +got): %s", diff)
+		t.Error("ExecActionMask (-want, +got):", diff)
 	}
 
 	if got = ExecActionMask(nil); got != nil {
@@ -322,9 +325,9 @@ func TestHTTPGetActionMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("HTTPGetActionMask (-want, +got): %s", diff)
+		t.Error("HTTPGetActionMask (-want, +got):", diff)
 	}
 
 	if got = HTTPGetActionMask(nil); got != nil {
@@ -348,9 +351,9 @@ func TestTCPSocketActionMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("TCPSocketActionMask (-want, +got): %s", diff)
+		t.Error("TCPSocketActionMask (-want, +got):", diff)
 	}
 
 	if got = TCPSocketActionMask(nil); got != nil {
@@ -379,9 +382,9 @@ func TestContainerPortMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("ContainerPortMask (-want, +got): %s", diff)
+		t.Error("ContainerPortMask (-want, +got):", diff)
 	}
 
 	if got = ContainerPortMask(nil); got != nil {
@@ -404,9 +407,9 @@ func TestEnvVarMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("EnvVarMask (-want, +got): %s", diff)
+		t.Error("EnvVarMask (-want, +got):", diff)
 	}
 
 	if got = EnvVarMask(nil); got != nil {
@@ -459,9 +462,9 @@ func TestEnvVarSourceMask(t *testing.T) {
 			}
 
 			if diff, err := kmp.SafeDiff(test.want, got); err != nil {
-				t.Errorf("Got error comparing output, err = %v", err)
+				t.Error("Got error comparing output, err =", err)
 			} else if diff != "" {
-				t.Errorf("EnvVarSourceMask (-want, +got): %s", diff)
+				t.Error("EnvVarSourceMask (-want, +got):", diff)
 			}
 
 			if got = EnvVarSourceMask(nil, test.fieldRef); got != nil {
@@ -484,9 +487,9 @@ func TestLocalObjectReferenceMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("LocalObjectReferenceMask (-want, +got): %s", diff)
+		t.Error("LocalObjectReferenceMask (-want, +got):", diff)
 	}
 
 	if got = LocalObjectReferenceMask(nil); got != nil {
@@ -509,9 +512,9 @@ func TestConfigMapKeySelectorMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("ConfigMapKeySelectorMask (-want, +got): %s", diff)
+		t.Error("ConfigMapKeySelectorMask (-want, +got):", diff)
 	}
 
 	if got = ConfigMapKeySelectorMask(nil); got != nil {
@@ -534,9 +537,9 @@ func TestSecretKeySelectorMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("SecretKeySelectorMask (-want, +got): %s", diff)
+		t.Error("SecretKeySelectorMask (-want, +got):", diff)
 	}
 
 	if got = SecretKeySelectorMask(nil); got != nil {
@@ -558,9 +561,9 @@ func TestConfigMapEnvSourceMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("ConfigMapEnvSourceMask (-want, +got): %s", diff)
+		t.Error("ConfigMapEnvSourceMask (-want, +got):", diff)
 	}
 
 	if got = ConfigMapEnvSourceMask(nil); got != nil {
@@ -582,9 +585,9 @@ func TestSecretEnvSourceMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("SecretEnvSourceMask (-want, +got): %s", diff)
+		t.Error("SecretEnvSourceMask (-want, +got):", diff)
 	}
 
 	if got = SecretEnvSourceMask(nil); got != nil {
@@ -607,9 +610,9 @@ func TestEnvFromSourceMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("EnvFromSourceMask (-want, +got): %s", diff)
+		t.Error("EnvFromSourceMask (-want, +got):", diff)
 	}
 
 	if got = EnvFromSourceMask(nil); got != nil {
@@ -631,9 +634,9 @@ func TestResourceRequirementsMask(t *testing.T) {
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("ResourceRequirementsMask (-want, +got): %s", diff)
+		t.Error("ResourceRequirementsMask (-want, +got):", diff)
 	}
 
 	if got = ResourceRequirementsMask(nil); got != nil {
@@ -641,10 +644,86 @@ func TestResourceRequirementsMask(t *testing.T) {
 	}
 }
 
+func TestPodSecurityContextMask(t *testing.T) {
+	in := &corev1.PodSecurityContext{
+		SELinuxOptions:     &corev1.SELinuxOptions{},
+		WindowsOptions:     &corev1.WindowsSecurityContextOptions{},
+		SupplementalGroups: []int64{},
+		Sysctls:            []corev1.Sysctl{},
+		RunAsUser:          ptr.Int64(1),
+		RunAsGroup:         ptr.Int64(1),
+		RunAsNonRoot:       ptr.Bool(true),
+		FSGroup:            ptr.Int64(1),
+	}
+
+	want := &corev1.PodSecurityContext{}
+	ctx := context.Background()
+
+	got := PodSecurityContextMask(ctx, in)
+
+	if &want == &got {
+		t.Error("Input and output share addresses. Want different addresses")
+	}
+
+	if diff, err := kmp.SafeDiff(want, got); err != nil {
+		t.Error("Got error comparing output, err =", err)
+	} else if diff != "" {
+		t.Error("PostSecurityContextMask (-want, +got):", diff)
+	}
+
+	if got = PodSecurityContextMask(ctx, nil); got != nil {
+		t.Errorf("PodSecurityContextMask(nil) = %v, want: nil", got)
+	}
+}
+
+func TestPodSecurityContextMask_FeatureEnabled(t *testing.T) {
+	in := &corev1.PodSecurityContext{
+		SELinuxOptions:     &corev1.SELinuxOptions{},
+		WindowsOptions:     &corev1.WindowsSecurityContextOptions{},
+		SupplementalGroups: []int64{1},
+		Sysctls:            []corev1.Sysctl{},
+		RunAsUser:          ptr.Int64(1),
+		RunAsGroup:         ptr.Int64(1),
+		RunAsNonRoot:       ptr.Bool(true),
+		FSGroup:            ptr.Int64(1),
+	}
+
+	want := &corev1.PodSecurityContext{
+		RunAsUser:          ptr.Int64(1),
+		RunAsGroup:         ptr.Int64(1),
+		RunAsNonRoot:       ptr.Bool(true),
+		FSGroup:            ptr.Int64(1),
+		SupplementalGroups: []int64{1},
+	}
+
+	ctx := config.ToContext(context.Background(),
+		&config.Config{
+			Features: &config.Features{
+				PodSpecSecurityContext: config.Enabled,
+			},
+		},
+	)
+
+	got := PodSecurityContextMask(ctx, in)
+
+	if &want == &got {
+		t.Error("Input and output share addresses. Want different addresses")
+	}
+
+	if diff, err := kmp.SafeDiff(want, got); err != nil {
+		t.Error("Got error comparing output, err =", err)
+	} else if diff != "" {
+		t.Error("PostSecurityContextMask (-want, +got):", diff)
+	}
+}
+
 func TestSecurityContextMask(t *testing.T) {
 	mtype := corev1.UnmaskedProcMount
 	want := &corev1.SecurityContext{
-		RunAsUser: ptr.Int64(1),
+		Capabilities:           &corev1.Capabilities{},
+		RunAsUser:              ptr.Int64(1),
+		RunAsNonRoot:           ptr.Bool(true),
+		ReadOnlyRootFilesystem: ptr.Bool(true),
 	}
 	in := &corev1.SecurityContext{
 		RunAsUser:                ptr.Int64(1),
@@ -658,19 +737,61 @@ func TestSecurityContextMask(t *testing.T) {
 		ProcMount:                &mtype,
 	}
 
-	got := SecurityContextMask(in)
+	got := SecurityContextMask(context.Background(), in)
 
 	if &want == &got {
 		t.Error("Input and output share addresses. Want different addresses")
 	}
 
 	if diff, err := kmp.SafeDiff(want, got); err != nil {
-		t.Errorf("Got error comparing output, err = %v", err)
+		t.Error("Got error comparing output, err =", err)
 	} else if diff != "" {
-		t.Errorf("SecurityContextMask (-want, +got): %s", diff)
+		t.Error("SecurityContextMask (-want, +got):", diff)
 	}
 
-	if got = SecurityContextMask(nil); got != nil {
+	if got = SecurityContextMask(context.Background(), nil); got != nil {
 		t.Errorf("SecurityContextMask(nil) = %v, want: nil", got)
 	}
 }
+
+func TestSecurityContextMask_FeatureEnabled(t *testing.T) {
+	mtype := corev1.UnmaskedProcMount
+	want := &corev1.SecurityContext{
+		Capabilities:           &corev1.Capabilities{},
+		RunAsGroup:             ptr.Int64(2),
+		RunAsNonRoot:           ptr.Bool(true),
+		RunAsUser:              ptr.Int64(1),
+		ReadOnlyRootFilesystem: ptr.Bool(true),
+	}
+	in := &corev1.SecurityContext{
+		AllowPrivilegeEscalation: ptr.Bool(true),
+		Capabilities:             &corev1.Capabilities{},
+		Privileged:               ptr.Bool(true),
+		ProcMount:                &mtype,
+		ReadOnlyRootFilesystem:   ptr.Bool(true),
+		RunAsGroup:               ptr.Int64(2),
+		RunAsNonRoot:             ptr.Bool(true),
+		RunAsUser:                ptr.Int64(1),
+		SELinuxOptions:           &corev1.SELinuxOptions{},
+	}
+
+	ctx := config.ToContext(context.Background(),
+		&config.Config{
+			Features: &config.Features{
+				PodSpecSecurityContext: config.Enabled,
+			},
+		},
+	)
+
+	got := SecurityContextMask(ctx, in)
+
+	if &want == &got {
+		t.Error("Input and output share addresses. Want different addresses")
+	}
+
+	if diff, err := kmp.SafeDiff(want, got); err != nil {
+		t.Error("Got error comparing output, err =", err)
+	} else if diff != "" {
+		t.Error("SecurityContextMask (-want, +got):", diff)
+	}
+}
