@@ -13,18 +13,22 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
+
 package v1
 
 import (
 	"testing"
+	"time"
 
 	corev1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	netv1alpha1 "knative.dev/networking/pkg/apis/networking/v1alpha1"
 	"knative.dev/pkg/apis"
 	"knative.dev/pkg/apis/duck"
 	duckv1 "knative.dev/pkg/apis/duck/v1"
 	apistest "knative.dev/pkg/apis/testing"
+	"knative.dev/serving/pkg/apis/serving"
 )
 
 func TestRouteDuckTypes(t *testing.T) {
@@ -162,9 +166,16 @@ func TestRouteIsReady(t *testing.T) {
 
 	for _, tc := range cases {
 		t.Run(tc.name, func(t *testing.T) {
-			if e, a := tc.isReady, tc.status.IsReady(); e != a {
+			r := Route{Status: tc.status}
+			if e, a := tc.isReady, r.IsReady(); e != a {
 				t.Errorf("%q expected: %v got: %v", tc.name, e, a)
 			}
+
+			r.Generation = 1
+			r.Status.ObservedGeneration = 2
+			if r.IsReady() {
+				t.Error("Expected IsReady() to be false when Generation != ObservedGeneration")
+			}
 		})
 	}
 }
@@ -471,3 +482,45 @@ func TestIngressNotConfigured(t *testing.T) {
 
 	apistest.CheckConditionOngoing(r, RouteConditionIngressReady, t)
 }
+
+func TestMarkInRollout(t *testing.T) {
+	r := &RouteStatus{}
+	r.InitializeConditions()
+	r.MarkIngressRolloutInProgress()
+
+	apistest.CheckConditionOngoing(r, RouteConditionIngressReady, t)
+}
+
+func TestRolloutDuration(t *testing.T) {
+	tests := []struct {
+		name string
+		val  string
+		want time.Duration
+	}{{
+		name: "empty",
+		val:  "",
+		want: 0,
+	}, {
+		name: "invalid",
+		val:  "not-a-duration",
+		want: 0,
+	}, {
+		name: "duration",
+		val:  "2m1982s",
+		want: 2*time.Minute + 1982*time.Second,
+	}}
+	for _, tc := range tests {
+		t.Run(tc.name, func(t *testing.T) {
+			r := &Route{
+				ObjectMeta: metav1.ObjectMeta{
+					Annotations: map[string]string{
+						serving.RolloutDurationKey: tc.val,
+					},
+				},
+			}
+			if got, want := r.RolloutDuration(), tc.want; got != want {
+				t.Errorf("RolloutDuration = %v, want: %v", got, want)
+			}
+		})
+	}
+}
