@@ -1,5 +1,5 @@
 /*
-Copyright 2018 The Knative Authors.
+Copyright 2018 The Knative Authors
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -21,16 +21,18 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
+	"github.com/google/go-cmp/cmp/cmpopts"
 	corev1 "k8s.io/api/core/v1"
+
+	network "knative.dev/networking/pkg"
+	"knative.dev/pkg/configmap"
 	"knative.dev/pkg/logging"
 	logtesting "knative.dev/pkg/logging/testing"
 	"knative.dev/pkg/metrics"
-	pkgmetrics "knative.dev/pkg/metrics"
 	pkgtracing "knative.dev/pkg/tracing/config"
-	apisconfig "knative.dev/serving/pkg/apis/config"
+	apiconfig "knative.dev/serving/pkg/apis/config"
 	autoscalerconfig "knative.dev/serving/pkg/autoscaler/config"
-	deployment "knative.dev/serving/pkg/deployment"
-	"knative.dev/serving/pkg/network"
+	"knative.dev/serving/pkg/deployment"
 
 	. "knative.dev/pkg/configmap/testing"
 )
@@ -40,40 +42,45 @@ func TestStoreLoadWithContext(t *testing.T) {
 
 	deploymentConfig := ConfigMapFromTestFile(t, deployment.ConfigName, deployment.QueueSidecarImageKey)
 	networkConfig := ConfigMapFromTestFile(t, network.ConfigName)
-	observabilityConfig, observabilityConfigExample := ConfigMapsFromTestFile(t, pkgmetrics.ConfigMapName())
+	observabilityConfig, observabilityConfigExample := ConfigMapsFromTestFile(t, metrics.ConfigMapName())
 	loggingConfig, loggingConfigExample := ConfigMapsFromTestFile(t, logging.ConfigMapName())
 	tracingConfig, tracingConfigExample := ConfigMapsFromTestFile(t, pkgtracing.ConfigName)
-	defaultConfig := ConfigMapFromTestFile(t, apisconfig.DefaultsConfigName)
+	defaultConfig := ConfigMapFromTestFile(t, apiconfig.DefaultsConfigName)
 	autoscalerConfig := ConfigMapFromTestFile(t, autoscalerconfig.ConfigName)
+	featuresConfig := ConfigMapFromTestFile(t, apiconfig.FeaturesConfigName)
 
-	store.OnConfigChanged(deploymentConfig)
-	store.OnConfigChanged(networkConfig)
-	store.OnConfigChanged(observabilityConfig)
-	store.OnConfigChanged(loggingConfig)
-	store.OnConfigChanged(tracingConfig)
-	store.OnConfigChanged(defaultConfig)
-	store.OnConfigChanged(autoscalerConfig)
+	watcher := configmap.NewStaticWatcher(
+		featuresConfig,
+		deploymentConfig,
+		networkConfig,
+		observabilityConfig,
+		loggingConfig,
+		tracingConfig,
+		defaultConfig,
+		autoscalerConfig)
+
+	store.WatchConfigs(watcher)
 
 	config := FromContext(store.ToContext(context.Background()))
 
 	t.Run("Deployment", func(t *testing.T) {
 		expected, _ := deployment.NewConfigFromConfigMap(deploymentConfig)
 		if diff := cmp.Diff(expected, config.Deployment); diff != "" {
-			t.Errorf("Unexpected deployment (-want, +got): %v", diff)
+			t.Error("Unexpected deployment (-want, +got):", diff)
 		}
 	})
 
 	t.Run("network", func(t *testing.T) {
 		expected, _ := network.NewConfigFromConfigMap(networkConfig)
 		if diff := cmp.Diff(expected, config.Network); diff != "" {
-			t.Errorf("Unexpected controller config (-want, +got): %v", diff)
+			t.Error("Unexpected controller config (-want, +got):", diff)
 		}
 	})
 
 	t.Run("observability", func(t *testing.T) {
 		expected, _ := metrics.NewObservabilityConfigFromConfigMap(observabilityConfig)
 		if diff := cmp.Diff(expected, config.Observability); diff != "" {
-			t.Errorf("Unexpected observability config (-want, +got): %v", diff)
+			t.Error("Unexpected observability config (-want, +got):", diff)
 		}
 
 		// Default config.
@@ -82,7 +89,10 @@ func TestStoreLoadWithContext(t *testing.T) {
 		if err != nil {
 			t.Fatal("Error parsing example observability config:", err)
 		}
-		if cmp.Equal(got, want) {
+
+		// Compare with the example and allow the log url template to differ
+		co := cmpopts.IgnoreFields(metrics.ObservabilityConfig{}, "LoggingURLTemplate")
+		if !cmp.Equal(got, want, co) {
 			t.Error("Example Observability Config does not match the default, diff(-want,+got):\n", cmp.Diff(want, got))
 		}
 	})
@@ -90,7 +100,7 @@ func TestStoreLoadWithContext(t *testing.T) {
 	t.Run("logging", func(t *testing.T) {
 		expected, _ := logging.NewConfigFromConfigMap(loggingConfig)
 		if diff := cmp.Diff(expected, config.Logging); diff != "" {
-			t.Errorf("Unexpected logging config (-want, +got): %v", diff)
+			t.Error("Unexpected logging config (-want, +got):", diff)
 		}
 
 		// Default config.
@@ -107,7 +117,7 @@ func TestStoreLoadWithContext(t *testing.T) {
 	t.Run("tracing", func(t *testing.T) {
 		expected, _ := pkgtracing.NewTracingConfigFromConfigMap(tracingConfig)
 		if diff := cmp.Diff(expected, config.Tracing); diff != "" {
-			t.Errorf("Unexpected tracing config (-want, +got): %v", diff)
+			t.Error("Unexpected tracing config (-want, +got):", diff)
 		}
 
 		// Default config.
@@ -122,30 +132,41 @@ func TestStoreLoadWithContext(t *testing.T) {
 	})
 
 	t.Run("defaults", func(t *testing.T) {
-		expected, _ := apisconfig.NewDefaultsConfigFromConfigMap(defaultConfig)
+		expected, _ := apiconfig.NewDefaultsConfigFromConfigMap(defaultConfig)
 		if diff := cmp.Diff(expected, config.Defaults); diff != "" {
-			t.Errorf("Unexpected defaults config (-want, +got): %v", diff)
+			t.Error("Unexpected defaults config (-want, +got):", diff)
 		}
 	})
 
 	t.Run("autoscaler", func(t *testing.T) {
 		expected, _ := autoscalerconfig.NewConfigFromConfigMap(autoscalerConfig)
 		if diff := cmp.Diff(expected, config.Autoscaler); diff != "" {
-			t.Errorf("Unexpected autoscaler config (-want, +got): %v", diff)
+			t.Error("Unexpected autoscaler config (-want, +got):", diff)
+		}
+	})
+
+	t.Run("features", func(t *testing.T) {
+		expected, _ := apiconfig.NewFeaturesConfigFromConfigMap(featuresConfig)
+		if diff := cmp.Diff(expected, config.Features); diff != "" {
+			t.Error("Unexpected autoscaler config (-want, +got):", diff)
 		}
 	})
 }
 
 func TestStoreImmutableConfig(t *testing.T) {
 	store := NewStore(logtesting.TestLogger(t))
+	watcher := configmap.NewStaticWatcher(
+		ConfigMapFromTestFile(t, deployment.ConfigName, deployment.QueueSidecarImageKey),
+		ConfigMapFromTestFile(t, network.ConfigName),
+		ConfigMapFromTestFile(t, metrics.ConfigMapName()),
+		ConfigMapFromTestFile(t, logging.ConfigMapName()),
+		ConfigMapFromTestFile(t, pkgtracing.ConfigName),
+		ConfigMapFromTestFile(t, apiconfig.DefaultsConfigName),
+		ConfigMapFromTestFile(t, autoscalerconfig.ConfigName),
+		ConfigMapFromTestFile(t, apiconfig.FeaturesConfigName),
+	)
 
-	store.OnConfigChanged(ConfigMapFromTestFile(t, deployment.ConfigName, deployment.QueueSidecarImageKey))
-	store.OnConfigChanged(ConfigMapFromTestFile(t, network.ConfigName))
-	store.OnConfigChanged(ConfigMapFromTestFile(t, pkgmetrics.ConfigMapName()))
-	store.OnConfigChanged(ConfigMapFromTestFile(t, logging.ConfigMapName()))
-	store.OnConfigChanged(ConfigMapFromTestFile(t, pkgtracing.ConfigName))
-	store.OnConfigChanged(ConfigMapFromTestFile(t, apisconfig.DefaultsConfigName))
-	store.OnConfigChanged(ConfigMapFromTestFile(t, autoscalerconfig.ConfigName))
+	store.WatchConfigs(watcher)
 
 	config := store.Load()
 
